==> v8.3.zip: ru_twords_ru_tw/bible/other/governor.md <==
# правитель, начальник, править

## Определение:

Правитель — это человек, управляющий государством. Править — значит руководить людьми, территорией или страной и распоряжаться имуществом.

* Проконсул — это наместник провинции в Древнем Риме.
* Проконсулы назначались на должность сенаторами или императорами.
* Правительство — это исполнительный, распорядительный и законодательный орган государственной власти, осуществляющий непосредственное управление государством. Правительство издаёт законы, регулирующие жизнь страны.

## Варианты перевода:

* Слово “правитель” можно перевести как “властелин”, “глава государства”, “вождь”, “начальник”.
* В зависимости от контекста глагол “править” можно перевести как “господствовать”, “руководить”, “управлять”, “надзирать”.
* В некоторых случаях слово “правитель” нужно переводить иначе, чем слово “царь” или “император”, поскольку “правитель” — это общее понятие. Оно распространяется на управление территориями, учреждениями и др. Правителем может быть человек, обладающий меньшей властью чем царь, император или какой-либо чиновник с высоким статусом.
* Слово “проконсул” можно перевести как “управляющий римской провинцией”.

(См. также: [власть](../kt/authority.md), [царь](../other/king.md), [сила](../kt/power.md), [провинция](../other/province.md), [Рим](../names/rome.md), [правитель](../other/ruler.md))

## Ссылки на библейский текст:

* [Деян. 7:9-10](rc://*/tn/help/act/07/09)
* [Деян. 23:22-24](rc://*/tn/help/act/23/22)
* [Деян. 26:30-32](rc://*/tn/help/act/26/30)
* [Мк. 13:9-10](rc://*/tn/help/mrk/13/09)
* [Мф. 10:16-18](rc://*/tn/help/mat/10/16)
* [Мф. 27:1-2](rc://*/tn/help/mat/27/01)

## Данные о слове:

* Номера Стронга: H324, H1777, H2280, H4951, H5148, H5460, H6346, H6347, H6486, H7989, H8269, H8660, G445, G446, G746, G1481, G2232, G2233, G2230, G4232

==> v9.2.zip: ru_twords_ru_tw/bible/other/governor.md <==
# правитель, начальник, править

## Определение:

Правитель — это человек, управляющий государством. Править — значит руководить людьми, территорией или страной и распоряжаться имуществом.

* Проконсул — это наместник провинции в Древнем Риме.
* Проконсулы назначались на должность сенаторами или императорами.
* Правительство — это исполнительный, распорядительный и законодательный орган государственной власти, осуществляющий непосредственное управление государством. Правительство издаёт законы, регулирующие жизнь страны.

## Варианты перевода:

* Слово “правитель” можно перевести как “властелин”, “глава государства”, “вождь”, “начальник”.
* В зависимости от контекста глагол “править” можно перевести как “господствовать”, “руководить”, “управлять”, “надзирать”. 
* В некоторых случаях слово “правитель” нужно переводить иначе, чем слово “царь” или “император”, поскольку “правитель” — это общее понятие. Оно распространяется на управление территориями, учреждениями и др. Правителем может быть человек, обладающий меньшей властью чем царь, император или какой-либо чиновник с высоким статусом. 
* Слово “проконсул” можно перевести как “управляющий римской провинцией”. 

(См. также: [власть](../kt/authority.md), [царь](../other/king.md), [сила](../kt/power.md), [провинция](../other/province.md), [Рим](../names/rome.md), [правитель](../other/ruler.md))

## Ссылки на библейский текст:

* [Деян. 7:9-10](rc://ru/tn/help/act/07/09)
* [Деян. 23:22-24](rc://ru/tn/help/act/23/22)
* [Деян. 26:30-32](rc://ru/tn/help/act/26/30)
* [Мк. 13:9-10](rc://ru/tn/help/mrk/13/09)
* [Мф. 10:16-18](rc://ru/tn/help/mat/10/16)
* [Мф. 27:1-2](rc://ru/tn/help/mat/27/01)

## Данные о слове:

* Номера Стронга: H324, H1777, H2280, H4951, H5148, H5460, H6346, H6347, H6486, H7989, H8269, H8660, G445, G446, G746, G1481, G2232, G2233, G2230, G4232
